//
//  BSAAd.h
//  BSAAdFramework
//
//  Created by Rick Fillion on 10/07/09.
//  Copyright 2009 BuySellAds. All rights reserved.
//

#import <Cocoa/Cocoa.h>

/**
 @brief The BSAAd class is the model class used to represent ads in BuySellAds.
 
 */
@interface BSAAd : NSObject {
    NSNumber *identifier;
    NSString *url;
    NSString *imageUrl;
    NSImage *image;
    NSString *title;
    NSString *text;
    NSArray *subads;
}

/// Unique identifier for the ad
@property (nonatomic, retain) NSNumber *identifier;
/// URL associated with the ad
@property (nonatomic, copy) NSString *url;
/// URL to the image file associated with the ad
@property (nonatomic, copy) NSString *imageUrl;
/// Image associated with the ad (loaded asynchronously upon initialization)
@property (nonatomic, retain) NSImage *image;
/// Title associated with the ad ("alt" property)
@property (nonatomic, copy) NSString *title;
/// Text associated with the ad ("text" property)
@property (nonatomic, copy) NSString *text;

/// Returns a placeholder ad that has its properties set to nil
+ (BSAAd *)placeholder;
/// Initializer used to create a BSAAd based on the JSON response from BuySellAds
/// converted into a NSDictionary
- (id)initWithDictionary:(NSDictionary *)dictionary;
/// Returns either self if the ad has no subads, or a random subad if the ad
/// contains any subads.  You should use this method instead of assuming that
/// a BSAAd instance is a full ad.
- (BSAAd *)adOrSubAd;

@end
